C-----******************************************************************PULV0000
C-----*              P  U  L  V  E  R  I  X                            *PULV0003
C-----******************************************************************PULV0006
C-----*                                                                *PULV0007
C-----* ROUTINE TO CALCULATE THEORETICAL POWDER PATTERNS               *PULV0008
C-----* USING THE DATA FILE PREPARED BY  L  A  Z  Y                    *PULV0009
C-----*                                                                *PULV0010
C-----* AUTHORS                                                        *PULV0011
C-----* K.YVON, W.JEITSCHKO  AND E.PARTHE                              *PULV0012
C-----*                                                                *PULV0013
C-----* ADDRESS                                                        *PULV0014
C-----* LABORATOIRE DE CRISTALLOGRAPHIE AUX RAYONS X                   *PULV0015
C-----* UNIVERSITY OF GENEVA                                           *PULV0016
C-----* 24 QUAI ERNEST ANSERMET , CH 1211 GENEVE, SWITZERLAND          *PULV0017
C-----* TEL  022 219355                                                *PULV0018
C-----*                                                                *PULV0019
C-----******************************************************************PULV0020
C-----*                                                                *PULV0021
C-----* R E M A R K S    FOR ADAPTING THE PROGRAM                      *PULV0022
C-----*                                                                *PULV0023
C-----* ILU        INPUT UNIT FROM  L A Z Y   (21)                     *PULV0031
C-----* IPR        LINE PRINTER (6)                                    *PULV0032
C-----*                                                                *PULV0033
C-----* LIMIT1     LIMIT ON NUMBER OF REFLECTIONS  (1000)              *PULV0034
C-----*            DIMENSIONS TO BE CHANGED                            *PULV0035
C-----*            Q,YH,YK,YL,THETA,SUMA,SUMB,VINT,STRU,FPLG,FMUL,     *PULV0036
C-----*            AX,AY,BX,BY,IDE                                     *PULV0037
C-----*                                                                *PULV0038
C-----* LIMIT2     LIMITATION ON DIFFERENT KINDS OF ATOMS (8)          *PULV0039
C-----*            DIMENSIONS TO BE CHANGED                            *PULV0040
C-----*            NA,X,Y,Z,FNEUT,BTEMP,ELEMT,FOCCU,DELFR,DELFI,       *PULV0041
C-----*            FMULT,FA,FB,FC,IDE                                  *PULV0042
C-----*                                                                *PULV0043
C-----* LIMIT3     LIMIT ON NUMBER OF ATOMS OF ONE KIND   (50)         *PULV0044
C-----*            DIMENSIONS TO BE CHANGED                            *PULV0045
C-----*            X,Y,Z,BTEMP,FOCCU,FMULT,IDE                         *PULV0046
C-----*                                                                *PULV0047
C-----* LIMIT4     LIMIT ON NUMBER OF EQUIVALENT POINTPOSITIONS (24)   *PULV0048
C-----*            DIMENSIONS TO BE CHANGED    TS, FS                  *PULV0049
C-----*                                                                *PULV0050
C-----* DG1        D-SPACING OF REFLECTING PLANES OF MONOCHROMATOR     *PULV0051
C-----*            IN GUINIER CAMERA 1 (3.343)   QUARZ                 *PULV0052
C-----*                                                                *PULV0053
C-----* DG2        D-SPACING OF REFLECTING PLANES OF MONOCHROMATOR     *PULV0054
C-----*            IN GUINIER CAMERA 2 (3.343)   QUARZ                 *PULV0055
C-----*                                                                *PULV0056
C-----* DM1        DIAMETER OF GUINIER CAMERA 1 IN MM (114.6)          *PULV0057
C-----* BG1        ANGLE BETWEEN NORMAL TO THE SPECIMEN AND INCIDENT   *PULV0058
C-----*            BEAM FOR CAMERA 1 (30 DEGREES)                      *PULV0059
C-----*                                                                *PULV0060
C-----* DM2        DIAMETER OF GUINIER CAMERA 2 IN MM (100.0)          *PULV0061
C-----* BG2        ANGLE BETWEEN NORMAL TO THE SPECIMEN AND INCIDENT   *PULV0062
C-----*            BEAM FOR CAMERA 2 (30 DEGREES)                      *PULV0063
C-----* GUINIER CAMERA 1  CORRESPONDS TO THE MODEL GUINIER-DE WOLFFII  *PULV0064
C-----* MANUFACTURED BY ENRAF NONIUS DELFT    (*GUINIER NONIUS*)       *PULV0065
C-----* GUINIER CAMERA 2  CORRESPONDS TO THE MODEL XDC-700 MANUFACTURED*PULV0066
C-----* BY IRD COMPANY SWEDEN                 (*GUINIER-HAEGG*)        *PULV0067
C-----*                                                                *PULV0068
C-----******************************************************************PULV0069
      DOUBLE PRECISION PI2,ARG,SMA,SMB,SUMA,SUMB,STRU,PRPINT            PULV0070
      DIMENSION Q(1000), YH(1000), YK(1000), YL(1000), THETA(1000), SUMAPULV0071
     1(1000), SUMB(1000), VINT(1000), NA(8), X(50,8), Y(50,8), Z(50,8), PULV0072
     2FNEUT(8), BTEMP(50,8), ELEMT(8), IPLA(100), COMPND(19), SP(900), WPULV0073
     3(900), FOCCU(50,8), STRU(1000), FPLG(1000), FMUL(1000), DELFR(8), PULV0074
     4DELFI(8), FMULT(50,8), IDT(9), IDL(25), TS(3,24), FS(3,3,24), FA(4PULV0075
     5,8), FB(4,8), FC(8), AX(1000), AY(1000), BX(1000), BY(1000), IDE(5PULV0076
     60,8), ITIT(13), NT(36), JB(21)                                    PULV0077
      COMMON /UNITS/ IPR                                                PULV0078
      COMMON /EQUO/ TS,FS,NS,ISYMCE,IBRAVL                              PULV0079
      DATA ITIT(1)/4H FOL/,ITIT(2)/4HLOWS/,ITIT(3)/4H OMI/,ITIT(4)/4HTTEPULV0080
     1D/,ITIT(5)/3H MM/,ITIT(6)/3H   /,ITIT(7)/3H2TH/,ITIT(8)/3HETA/,ITIPULV0081
     2T(9)/4H NOT/,ITIT(10)/4HLOW /,ITIT(11)/4HHIGH/,ITIT(12)/2HNO/,ITITPULV0082
     3(13)/2H A/                                                        PULV0083
      DATA JB(1)/4HPRIM/,JB(2)/4HITIV/,JB(3)/4HE   /,JB(4)/4HBODY/,JB(5)PULV0084
     1/4H CEN/,JB(6)/4HTRED/,JB(7)/4HRHOM/,JB(8)/4HBOHE/,JB(9)/4HDRAL/,JPULV0085
     2B(10)/4HFACE/,JB(11)/4H CEN/,JB(12)/4HTRED/,JB(13)/4HA -C/,JB(14)/PULV0086
     34HENTR/,JB(15)/4HED  /,JB(16)/4HB -C/,JB(17)/4HENTR/,JB(18)/4HED  PULV0087
     4/,JB(19)/4HC -C/,JB(20)/4HENTR/,JB(21)/4HED  /                    PULV0088
      DATA ISTA/1H*/,IBLNK/1H /                                         PULV0089
      DATA IDT(1)/1H1/,IDT(2)/1H2/,IDT(3)/1H3/,IDT(4)/1H4/,IDT(5)/1H5/,IPULV0090
     1DT(6)/1H6/,IDT(7)/1H7/,IDT(8)/1H8/,IDT(9)/1H9/                    PULV0091
      DATA IDL(1)/4H DEB/,IDL(2)/4HYE S/,IDL(3)/4HCHER/,IDL(4)/4HRER /,IPULV0092
     1DL(5)/4H    /,IDL(6)/4HSPEC/,IDL(7)/4HIAL /,IDL(8)/4HWITH/,IDL(9)/PULV0093
     24H LP=/,IDL(10)/4H1   /,IDL(11)/4H NEU/,IDL(12)/4HTRON/,IDL(13)/4HPULV0094
     3 DIF/,IDL(14)/4HFRAC/,IDL(15)/4HTION/,IDL(16)/4H    /,IDL(17)/4H GPULV0095
     4UI/,IDL(18)/4HNIER/,IDL(19)/4H CAM/,IDL(20)/4HERA /,IDL(21)/4H GUIPULV0096
     5/,IDL(22)/4HNIER/,IDL(23)/4H CAM/,IDL(24)/4HERA /,IDL(25)/4H    / PULV0097
C-----                                                                  PULV0098
C-----CHANGE THE FOLLOWING PARAMETERS IF NECESSARY                      PULV0099
C-----                                                                  PULV0100
      IPR=6                                                             PULV0101
      ILU=21                                                            PULV0103
      LIMIT1=1000                                                       PULV0105
      LIMIT2=8                                                          PULV0106
      LIMIT3=50                                                         PULV0107
      LIMIT4=24                                                         PULV0108
      DG1=3.343                                                         PULV0109
      DG2=3.343                                                         PULV0110
      DM1=114.59156                                                     PULV0111
      DM2=100.                                                          PULV0112
      BG1=30.                                                           PULV0113
      BG2=30.                                                           PULV0114
C-----                                                                  PULV0115
C-----END OF PARAMETERS                                                 PULV0116
C-----                                                                  PULV0117
      NFI=0                                                             PULV0118
      PI2=6.283185307179586D0                                           PULV0119
      E=2.7182818                                                       PULV0120
      FRTD=4./3.                                                        PULV0121
C-----READ INPUT FROM BINARY DATA FILE ILU                              PULV0122
      REWIND ILU                                                        PULV0123
C-----READ NUMBER OF FILES ON ILU                                       PULV0124
      READ (ILU) NFIL                                                   PULV0125
      WRITE (IPR,138)                                                   PULV0126
 1    NFI=NFI+1                                                         PULV0127
      WRITE (IPR,141)                                                   PULV0128
      IF (NFI.LE.NFIL) GO TO 2                                          PULV0129
      WRITE (IPR,139)                                                   PULV0130
      GO TO 137                                                         PULV0131
 2    READ (ILU) (COMPND(I),I=1,19),A,B,C,ALPHA,BETA,GAMMA,WL,(NT(I),I=1PULV0132
     1,36),IGROUP, IWL, ILP                                             PULV0133
      IF (A.GT.0.) GO TO 3                                              PULV0134
      WRITE (IPR,140) NFI                                               PULV0135
      GO TO 1                                                           PULV0136
 3    READ (ILU) ISYSTM,ISYMCE,IBRAVL,NS,TL,TH,NORM,IMAGE,ANO,KODLP,NCOMPULV0137
     1PO,(NA(I),I=1,8),IHOO,IOKO,IOOL,IHHL,IHOL,IHKO,IOKL,LAUE          PULV0138
      IF (NS.GT.LIMIT4) GO TO 136                                       PULV0139
      IF (NCOMPO.GT.LIMIT2) GO TO 134                                   PULV0140
      READ (ILU) ((TS(I,II),(FS(K,I,II),K=1,3),I=1,3),II=1,NS)          PULV0141
      DO 4 M=1,NCOMPO                                                   PULV0142
      NL=NA(M)                                                          PULV0143
      IF (NL.GT.LIMIT3) GO TO 135                                       PULV0144
      READ (ILU) DELFR(M),DELFI(M)                                      PULV0145
      READ (ILU) ELEMT(M),(FA(I,M),FB(I,M),I=1,4),FC(M),FNEUT(M)        PULV0146
      READ (ILU) (ELEMT(M),IDE(I,M),X(I,M),Y(I,M),Z(I,M),FMULT(I,M),FOCCPULV0147
     1U(I,M),BTEMP(I,M),I=1,NL)                                         PULV0148
 4    CONTINUE                                                          PULV0149
C-----SET VARIABLES BACK TO ORIGINAL VALUE                              PULV0150
      WRITE (IPR,142) NFI                                               PULV0151
C-----PRINT FIRST LINE OF TITLE                                         PULV0152
      VMXINT=0                                                          PULV0153
      NLINE=0                                                           PULV0154
      N=0                                                               PULV0155
      ICON=0                                                            PULV0156
      DUM=1.                                                            PULV0157
      BGUIN=BG1                                                         PULV0158
      DGU=DG1                                                           PULV0159
C-----                                                                  PULV0160
      K=KODLP+1                                                         PULV0161
      GO TO (7,7,7,5,6), K                                              PULV0162
C-----GUINIER NONIUS GEOMETRY                                           PULV0163
 5    DURCHM=DM1                                                        PULV0164
      GO TO 7                                                           PULV0165
C-----GUINIER HAEGG  GEOMETRY                                           PULV0166
 6    DURCHM=DM2                                                        PULV0167
      BGUIN=BG2                                                         PULV0168
      DGU=DG2                                                           PULV0169
C-----CALCULATE CORRECTION TERM FOR LP FACTOR                           PULV0170
 7    AGUIN=(1-WL*WL/(2.*DGU*DGU))**2.                                  PULV0171
C-----MULTIPLICITY FOR BRAVAIS LATTICE                                  PULV0172
      FBRA=IBRAVL                                                       PULV0173
      IF (FBRA.GT.4.) FBRA=2.                                           PULV0174
C-----MULTIPLIER IF CENTER OF SYMMETRY AT ORIGIN                        PULV0175
      IF (ISYMCE.NE.0) DUM=2.                                           PULV0176
C-----CALCULATE SIN**2 THETA LIMITS                                     PULV0177
      SH=TH*PI2/360.                                                    PULV0178
      SL=TL*PI2/360.                                                    PULV0179
      SH=(SIN(SH))**2                                                   PULV0180
      SL=(SIN(SL))**2                                                   PULV0181
C-----PRINT TITLE                                                       PULV0182
      WRITE (IPR,165) COMPND                                            PULV0183
      WLSQ4=WL**2/4.                                                    PULV0184
      ASTAR=WLSQ4/A**2                                                  PULV0185
      IF ((ISYSTM.EQ.1).OR.(ISYSTM.EQ.2).OR.(ISYSTM.EQ.7)) BSTAR=WLSQ4/BPULV0186
     1**2                                                               PULV0187
      IF (ISYSTM.NE.5) CSTAR=WLSQ4/C**2                                 PULV0188
      BET=BETA*PI2/360.                                                 PULV0189
      SINB2=(SIN(BET))**2                                               PULV0190
      COSB=COS(BET)                                                     PULV0191
C-----TRICLINIC CASE                                                    PULV0192
      IF (ISYSTM.NE.7) GO TO 8                                          PULV0193
      ALPH=ALPHA*PI2/360.                                               PULV0194
      GAMM=GAMMA*PI2/360.                                               PULV0195
      SV=(ALPH+BET+GAMM)/2.                                             PULV0196
      VOL=2.*A*B*C*SQRT(SIN(SV)*SIN(SV-ALPH)*SIN(SV-BET)*SIN(SV-GAMM))  PULV0197
      AST=(B*C*SIN(ALPH))/VOL                                           PULV0198
      BST=(A*C*SIN(BET))/VOL                                            PULV0199
      CST=(A*B*SIN(GAMM))/VOL                                           PULV0200
      COAST=(COSB*COS(GAMM)-COS(ALPH))/(SIN(BET)*SIN(GAMM))             PULV0201
      COBST=(COS(GAMM)*COS(ALPH)-COSB)/(SIN(GAMM)*SIN(ALPH))            PULV0202
      COGST=(COS(ALPH)*COSB-COS(GAMM))/(SIN(ALPH)*SIN(BET))             PULV0203
C-----START LOOP TO FIND HKL LIMITS FOR GIVEN SL AND SH LIMITS          PULV0204
 8    ZH=0.                                                             PULV0205
      ZK=0.                                                             PULV0206
      ZL=0.                                                             PULV0207
 9    ZH=ZH+1.                                                          PULV0208
      GO TO (10,15,16,21,22,23,24), ISYSTM                              PULV0209
C-----MONOCLINIC                                                        PULV0210
 10   ZHTEST=(2.0*A*SQRT(SH))/WL                                        PULV0211
      IF (ZH.LE.ZHTEST) GO TO 13                                        PULV0212
      ZH=0.                                                             PULV0213
      ZK=ZK+1.                                                          PULV0214
      ZKTEST=(2.0*B*SQRT(SH))/WL                                        PULV0215
      IF (ZK.LE.ZKTEST) GO TO 10                                        PULV0216
      ZK=0.                                                             PULV0217
      IF (ICON.EQ.0) GO TO 11                                           PULV0218
      ZL=ZL-1.                                                          PULV0219
      GO TO 12                                                          PULV0220
 11   ZL=ZL+1.                                                          PULV0221
 12   ZLTEST=(2.0*C*SQRT(SH))/WL                                        PULV0222
      IF (ABS(ZL).LE.ZLTEST) GO TO 10                                   PULV0223
      IF (ICON.EQ.1) GO TO 14                                           PULV0224
      ICON=1                                                            PULV0225
      GO TO 8                                                           PULV0226
 13   ATEST=ASTAR*ZH**2/SINB2+BSTAR*ZK**2+CSTAR*ZL**2/SINB2-WLSQ4*2.*ZH*PULV0227
     1ZL*COSB/(A*C*SINB2)                                               PULV0228
      IF (ATEST.GT.SH) GO TO 9                                          PULV0229
      IF ((ICON.EQ.0).OR.((ZH.GT.0.9).AND.(ZL.LT.(-0.9)))) GO TO 31     PULV0230
      GO TO 9                                                           PULV0231
 14   WRITE (IPR,187)                                                   PULV0232
      WRITE (IPR,168) A,B,C,BETA,WL                                     PULV0233
      GO TO 73                                                          PULV0234
C-----ORTHORHOMBIC                                                      PULV0235
 15   ATEST=ASTAR*ZH**2+BSTAR*ZK**2+CSTAR*ZL**2                         PULV0236
      IF (ATEST.LE.SH) GO TO 31                                         PULV0237
      ZH=0.                                                             PULV0238
      ZK=ZK+1.                                                          PULV0239
      BTEST=BSTAR*ZK**2+CSTAR*ZL**2                                     PULV0240
      IF (BTEST.LE.SH) GO TO 15                                         PULV0241
      ZK=0.                                                             PULV0242
      ZL=ZL+1.                                                          PULV0243
      CTEST=CSTAR*ZL**2                                                 PULV0244
      IF (CTEST.LE.SH) GO TO 15                                         PULV0245
      WRITE (IPR,189)                                                   PULV0246
      WRITE (IPR,169) A,B,C,WL                                          PULV0247
      GO TO 73                                                          PULV0248
C-----TRIGONAL                                                          PULV0249
 16   ATEST=FRTD*ASTAR*(ZH**2+ZH*ZK+ZK**2)+CSTAR*ZL**2                  PULV0250
      IF ((ZH.EQ.0.).AND.(ZL.EQ.0.)) GO TO 9                            PULV0251
      IF (ATEST.LE.SH) GO TO 19                                         PULV0252
      ZH=0.                                                             PULV0253
      ZK=ZK+1.                                                          PULV0254
      BTEST=FRTD*ASTAR*ZK**2+CSTAR*ZL**2                                PULV0255
      IF (BTEST.LE.SH) GO TO 16                                         PULV0256
      ZK=0.                                                             PULV0257
      IF (ICON.EQ.0) GO TO 17                                           PULV0258
      ZL=ZL-1.                                                          PULV0259
      GO TO 18                                                          PULV0260
 17   ZL=ZL+1.                                                          PULV0261
 18   CTEST=CSTAR*ZL**2                                                 PULV0262
      IF (CTEST.LE.SH) GO TO 16                                         PULV0263
      IF (ICON.EQ.1) GO TO 20                                           PULV0264
      ICON=1                                                            PULV0265
      GO TO 8                                                           PULV0266
 19   IF ((ICON.EQ.0).OR.((ZL.LT.(-0.9)).AND.((ZH.NE.0.).AND.(ZK.NE.0.))PULV0267
     1)) GO TO 31                                                       PULV0268
      GO TO 9                                                           PULV0269
 20   WRITE (IPR,190)                                                   PULV0270
      GO TO 72                                                          PULV0271
C-----TETRAGONAL                                                        PULV0272
 21   ATEST=ASTAR*(ZH**2+ZK**2)+CSTAR*ZL**2                             PULV0273
      IF (ATEST.LE.SH) GO TO 31                                         PULV0274
      ZH=ZK+1.                                                          PULV0275
      ZK=ZH                                                             PULV0276
      BTEST=ASTAR*2.*ZH**2+CSTAR*ZL**2                                  PULV0277
      IF (BTEST.LE.SH) GO TO 21                                         PULV0278
      ZH=0.                                                             PULV0279
      ZK=0.                                                             PULV0280
      ZL=ZL+1.                                                          PULV0281
      CTEST=CSTAR*ZL**2                                                 PULV0282
      IF (CTEST.LE.SH) GO TO 21                                         PULV0283
      WRITE (IPR,191)                                                   PULV0284
      GO TO 72                                                          PULV0285
C-----CUBIC                                                             PULV0286
 22   ATEST=ASTAR*(ZH**2+ZK**2+ZL**2)                                   PULV0287
      IF (ATEST.LE.SH) GO TO 31                                         PULV0288
      ZH=ZK+1.                                                          PULV0289
      ZK=ZH                                                             PULV0290
      BTEST=ASTAR*(2.*ZH**2+ZL**2)                                      PULV0291
      IF (BTEST.LE.SH) GO TO 22                                         PULV0292
      ZH=ZL+1.                                                          PULV0293
      ZK=ZH                                                             PULV0294
      ZL=ZH                                                             PULV0295
      CTEST=ASTAR*3.*ZH**2                                              PULV0296
      IF (CTEST.LE.SH) GO TO 22                                         PULV0297
      WRITE (IPR,192)                                                   PULV0298
      WRITE (IPR,171) A,WL                                              PULV0299
      GO TO 73                                                          PULV0300
C-----HEXAGONAL                                                         PULV0301
 23   ATEST=FRTD*ASTAR*(ZH**2+ZH*ZK+ZK**2)+CSTAR*ZL**2                  PULV0302
      IF (ATEST.LE.SH) GO TO 31                                         PULV0303
      ZH=ZK+1.                                                          PULV0304
      ZK=ZH                                                             PULV0305
      BTEST=FRTD*ASTAR*3.*ZH**2+CSTAR*ZL**2                             PULV0306
      IF (BTEST.LE.SH) GO TO 23                                         PULV0307
      ZH=0.                                                             PULV0308
      ZK=0.                                                             PULV0309
      ZL=ZL+1.                                                          PULV0310
      CTEST=CSTAR*ZL**2                                                 PULV0311
      IF (CTEST.LE.SH) GO TO 23                                         PULV0312
      WRITE (IPR,193)                                                   PULV0313
      GO TO 72                                                          PULV0314
C-----TRICLINIC                                                         PULV0315
 24   ZHTEST=(2.0*A*SQRT(SH))/WL                                        PULV0316
      IF (ZH.LE.ZHTEST) GO TO 29                                        PULV0317
      ZH=0.                                                             PULV0318
      IF (ICON.LT.2) GO TO 25                                           PULV0319
      ZK=ZK-1.                                                          PULV0320
      GO TO 26                                                          PULV0321
 25   ZK=ZK+1.                                                          PULV0322
 26   ZKTEST=(2.0*B*SQRT(SH))/WL                                        PULV0323
      IF (ABS(ZK).LE.ZKTEST) GO TO 24                                   PULV0324
      ZK=0.                                                             PULV0325
      IF ((ICON.EQ.0).OR.(ICON.EQ.2)) GO TO 27                          PULV0326
      ZL=ZL-1.                                                          PULV0327
      GO TO 28                                                          PULV0328
 27   ZL=ZL+1.                                                          PULV0329
 28   ZLTEST=(2.0*C*SQRT(SH))/WL                                        PULV0330
      IF (ABS(ZL).LE.ZLTEST) GO TO 24                                   PULV0331
      ICON=ICON+1                                                       PULV0332
      GO TO (8,8,8,30), ICON                                            PULV0333
 29   ATEST=WLSQ4*((ZH*AST)**2+(ZK*BST)**2+(ZL*CST)**2+2.*ZK*ZL*BST*CST*PULV0334
     1COAST+2.*ZH*ZL*AST*CST*COBST+2.*ZH*ZK*AST*BST*COGST)              PULV0335
      IF (ATEST.GT.SH) GO TO 9                                          PULV0336
      IF (ICON.EQ.0) GO TO 31                                           PULV0337
      IF (((ZH.EQ.0.).AND.(ZK.EQ.0.)).OR.((ZK.EQ.0.).AND.(ZL.EQ.0.)).OR.PULV0338
     1((ZH.EQ.0.).AND.(ZL.EQ.0.))) GO TO 9                              PULV0339
      IF ((ICON.EQ.1).AND.(ZL.LT.(-0.9))) GO TO 31                      PULV0340
      IF (((ICON.EQ.2).AND.(ZK.LT.(-0.9))).AND.(ZH.GT.0.9)) GO TO 31    PULV0341
      IF ((ICON.EQ.3).AND.((ZH*ZK*ZL).NE.0.)) GO TO 31                  PULV0342
      GO TO 9                                                           PULV0343
C-----PRINT TRICLINIC LATTICE CONSTANTS                                 PULV0344
 30   WRITE (IPR,188)                                                   PULV0345
      WRITE (IPR,172) A,B,C,ALPHA,BETA,GAMMA,WL                         PULV0346
      GO TO 73                                                          PULV0347
 31   IF (ATEST.LT.SL) GO TO 9                                          PULV0348
      XH=ZH                                                             PULV0349
      XK=ZK                                                             PULV0350
      XL=ZL                                                             PULV0351
C-----OMIT HKL VALUES CORRESPONDING TO BRAVAIS LATTICE EXTINCTIONS      PULV0352
 32   GO TO (40,33,34,35,36,37,38), IBRAVL                              PULV0353
 33   TESTBR=(XH+XK+XL)/2.                                              PULV0354
      GO TO 39                                                          PULV0355
 34   TESTBR=(-XH+XK+XL)/3.                                             PULV0356
      GO TO 39                                                          PULV0357
 35   FACEHK=(XH+XK)/2.                                                 PULV0358
      IF ((AINT(FACEHK)-FACEHK).NE.0.) GO TO 9                          PULV0359
 36   TESTBR=(XK+XL)/2.                                                 PULV0360
      GO TO 39                                                          PULV0361
 37   TESTBR=(XH+XL)/2.                                                 PULV0362
      GO TO 39                                                          PULV0363
 38   TESTBR=(XH+XK)/2.                                                 PULV0364
 39   IF ((AINT(TESTBR)-TESTBR).NE.0.) GO TO 68                         PULV0365
C-----OMIT HKL VALUES CORRESPONDING TO EXTINCTIONS                      PULV0366
 40   IF (XL.EQ.0.) GO TO (41,50,49,50,47), IHKO                        PULV0367
 41   IF (XH.EQ.0.) GO TO (42,54,53,54,51), IOKL                        PULV0368
 42   IF (XK.EQ.0.) GO TO (43,58,57,58,55), IHOL                        PULV0369
 43   IF (XH.EQ.XK) GO TO (44,59,61), IHHL                              PULV0370
      IF ((XK.EQ.XL).AND.(ISYSTM.EQ.5)) GO TO (44,62,44,63), IHHL       PULV0371
 44   IF (XK.EQ.0..AND.XL.EQ.0.) GO TO (45,64,133,64), IHOO             PULV0372
 45   IF (XH.EQ.0..AND.XL.EQ.0.) GO TO (46,65,133,65), IOKO             PULV0373
 46   IF (XH.EQ.0..AND.XK.EQ.0.) GO TO (67,66,66,66,133,66), IOOL       PULV0374
      GO TO 67                                                          PULV0375
 47   FIHKO=XH/2.                                                       PULV0376
 48   IF (AINT(FIHKO)-FIHKO) 68,41,68                                   PULV0377
 49   FIHKO=XK/2.                                                       PULV0378
      GO TO 48                                                          PULV0379
 50   HKO=IHKO                                                          PULV0380
      FIHKO=(XH+XK)/HKO                                                 PULV0381
      GO TO 48                                                          PULV0382
 51   FIOKL=XK/2.                                                       PULV0383
 52   IF (AINT(FIOKL)-FIOKL) 68,42,68                                   PULV0384
 53   FIOKL=XL/2.                                                       PULV0385
      GO TO 52                                                          PULV0386
 54   OKL=IOKL                                                          PULV0387
      FIOKL=(XK+XL)/OKL                                                 PULV0388
      GO TO 52                                                          PULV0389
 55   FIHOL=XH/2.                                                       PULV0390
 56   IF (AINT(FIHOL)-FIHOL) 68,43,68                                   PULV0391
 57   FIHOL=XL/2.                                                       PULV0392
      GO TO 56                                                          PULV0393
 58   HOL=IHOL                                                          PULV0394
      FIHOL=(XH+XL)/HOL                                                 PULV0395
      GO TO 56                                                          PULV0396
 59   FIHHL=XL/2.                                                       PULV0397
 60   IF (AINT(FIHHL)-FIHHL) 68,44,68                                   PULV0398
 61   FIHHL=(2.*XH+XL)/4.                                               PULV0399
      GO TO 60                                                          PULV0400
 62   FIHHL=XH/2.                                                       PULV0401
      GO TO 60                                                          PULV0402
 63   FIHHL=(2.*XL+XH)/4.                                               PULV0403
      GO TO 60                                                          PULV0404
 64   HOO=IHOO                                                          PULV0405
      FIHOO=XH/HOO                                                      PULV0406
      IF (AINT(FIHOO)-FIHOO) 68,45,68                                   PULV0407
 65   FIOKO=XK/2.                                                       PULV0408
      IF (AINT(FIOKO)-FIOKO) 68,46,68                                   PULV0409
 66   OOL=IOOL                                                          PULV0410
      FIOOL=XL/OOL                                                      PULV0411
      IF ((AINT(FIOOL)-FIOOL).NE.0.) GO TO 68                           PULV0412
C-----STORE HKL AND SIN2THETA VALUES OF F VALUES  TO BE CALCULATED      PULV0413
 67   N=N+1                                                             PULV0414
C-----CHECK IF NUMBER OF REFLECTIONS TOO LARGE                          PULV0415
      IF (N.GT.LIMIT1) GO TO 132                                        PULV0416
      Q(N)=ATEST                                                        PULV0417
      YH(N)=XH                                                          PULV0418
      YK(N)=XK                                                          PULV0419
      YL(N)=XL                                                          PULV0420
      JJ=N                                                              PULV0421
      J=JJ-1                                                            PULV0422
C-----SKIP REFLECTIONS RELATED BY LAUE SYMMETRY                         PULV0423
 68   IF ((LAUE.EQ.2).OR.(ZH.EQ.XK)) GO TO 9                            PULV0424
      GO TO (9,9,9,69,70,69,9), ISYSTM                                  PULV0425
 69   IF ((ZH.GT.ZK).AND.(ZK.GT.0.)) GO TO 71                           PULV0426
      GO TO 9                                                           PULV0427
 70   IF ((ZH.GT.ZK).AND.(ZK.GT.ZL)) GO TO 71                           PULV0428
      GO TO 9                                                           PULV0429
 71   TEMP=XH                                                           PULV0430
      XH=XK                                                             PULV0431
      XK=TEMP                                                           PULV0432
      GO TO 32                                                          PULV0433
C-----PRINT HEX AND TETRAG LATTICE CONSTANTS, END OF HKL GENER.LOOP     PULV0434
 72   WRITE (IPR,170) A,C,WL                                            PULV0435
 73   MP=KODLP*5+1                                                      PULV0436
      KK=MP+4                                                           PULV0437
      WRITE (IPR,173) TL,TH,(IDL(I),I=MP,KK)                            PULV0438
C-----CHECK IF NUMBER OF REFLECTIONS TOO LARGE                          PULV0439
      IF(N.GT.LIMIT1) GO TO 132                                         PULV0440
C-----PRINT DIFFRACTION GEOMETRY                                        PULV0441
      IF (KODLP.GT.2) WRITE (IPR,143) DURCHM,BGUIN,DGU                  PULV0442
C-----PRINT SPACE GROUP AND EQUIVALENT POSITIONS                        PULV0443
      N=6                                                               PULV0444
      IF (IGROUP.EQ.0) N=9                                              PULV0445
      WRITE (IPR,144) ITIT(N),(NT(I),I=1,36)                            PULV0446
      CALL EQUI                                                         PULV0447
C-----PRINT LAUE SYMMETRY                                               PULV0448
      IF (ISYSTM.LT.3) GO TO 74                                         PULV0449
      N=10                                                              PULV0450
      IF (LAUE.EQ.2) N=11                                               PULV0451
      WRITE (IPR,145) ITIT(N)                                           PULV0452
 74   N=12                                                              PULV0453
C-----PRINT SYMMETRY CENTER                                             PULV0454
      IF (ISYMCE.EQ.1) N=13                                             PULV0455
      WRITE (IPR,146) ITIT(N)                                           PULV0456
C-----PRINT BRAVAIS LATTICE AND EXTINCTIONS                             PULV0457
      N=IBRAVL*3-2                                                      PULV0458
      WRITE (IPR,147) JB(N),JB(N+1),JB(N+2)                             PULV0459
      WRITE (IPR,148)                                                   PULV0460
      IF(IBRAVL.EQ.1) WRITE(IPR,208)                                    PULV0461
      IF(IBRAVL.EQ.2) WRITE(IPR,213)                                    PULV0462
      IF(IBRAVL.EQ.3) WRITE(IPR,214)                                    PULV0463
      IF(IBRAVL.EQ.4) WRITE(IPR,212)                                    PULV0464
      IF(IBRAVL.EQ.5) WRITE(IPR,209)                                    PULV0465
      IF(IBRAVL.EQ.6) WRITE(IPR,215)                                    PULV0466
      IF(IBRAVL.EQ.7) WRITE(IPR,211)                                    PULV0467
      IF ((IHKO.EQ.2).OR.(IHKO.EQ.4)) WRITE (IPR,176) IHKO              PULV0468
      IF (IHKO.EQ.3) WRITE (IPR,175)                                    PULV0469
      IF (IHKO.EQ.5) WRITE (IPR,174)                                    PULV0470
      IF ((IOKL.EQ.2).OR.(IOKL.EQ.4)) WRITE (IPR,178) IOKL              PULV0471
      IF (IOKL.EQ.3) WRITE (IPR,210)                                    PULV0472
      IF (IOKL.EQ.5) WRITE (IPR,177)                                    PULV0473
      IF ((IHOL.EQ.2).OR.(IHOL.EQ.4)) WRITE (IPR,181) IHOL              PULV0474
      IF (IHOL.EQ.3) WRITE (IPR,180)                                    PULV0475
      IF (IHOL.EQ.5) WRITE (IPR,179)                                    PULV0476
      IF (IHHL.EQ.2) WRITE (IPR,182)                                    PULV0477
      IF (IHHL.EQ.3) WRITE (IPR,183)                                    PULV0478
      IF (IHOO.GT.1) WRITE (IPR,184) IHOO                               PULV0479
      IF (IOKO.GT.1) WRITE (IPR,185) IOKO                               PULV0480
      IF (IOOL.GT.1) WRITE (IPR,186) IOOL                               PULV0481
C-----PRINT NUMBER AND KINDS OF ATOMS IN UNIT CELL                      PULV0482
      WRITE (IPR,196)                                                   PULV0483
C-----NUMBER OF GENERAL POINT POSITIONS                                 PULV0484
      GEN=DUM*NS*FBRA                                                   PULV0485
      DO 75 M=1,NCOMPO                                                  PULV0486
      NL=NA(M)                                                          PULV0487
      DO 75 I=1,NL                                                      PULV0488
C-----NUMBER OF SPECIAL POINT POSITIONS                                 PULV0489
      FMULI=GEN*FMULT(I,M)                                              PULV0490
      SATO=FMULI*FOCCU(I,M)                                             PULV0491
 75   WRITE (IPR,197) ELEMT(M),IDE(I,M),FMULI,FOCCU(I,M),SATO           PULV0492
C-----CALCULATE NUMBER OF ELECTRONS AND PRINT X RAY SCATTERING FACTORS  PULV0493
      WRITE (IPR,149)                                                   PULV0494
      SATO=0                                                            PULV0495
      DO 78 M=1,NCOMPO                                                  PULV0496
      IF (KODLP.NE.2) GO TO 76                                          PULV0497
C-----PRINT NEUTRON SCATTERING LENGTH                                   PULV0498
      WRITE (IPR,150) ELEMT(M),FNEUT(M)                                 PULV0499
      GO TO 78                                                          PULV0500
 76   FSCAT=0.                                                          PULV0501
      DO 77 I=1,4                                                       PULV0502
      FSCAT=FSCAT+FA(I,M)                                               PULV0503
 77   CONTINUE                                                          PULV0504
      INEL=FSCAT+FC(M)+0.1                                              PULV0505
      WRITE (IPR,151) ELEMT(M),(FA(I,M),FB(I,M),I=1,4),FC(M),INEL       PULV0506
      WRITE (IPR,152) DELFR(M),DELFI(M)                                 PULV0507
C-----CALCULATE F(000)                                                  PULV0508
      NL=NA(M)                                                          PULV0509
      DO 278 I=1,NL                                                     PULV0510
 278  SATO=SATO+GEN*INEL*FMULT(I,M)*FOCCU(I,M)                          PULV0511
 78   CONTINUE                                                          PULV0512
C-----INDICATE ANOMALOUS DISPERSION CORRECTION                          PULV0513
      IF (ANO.EQ.0.)WRITE (IPR,153)                                     PULV0514
      IF (ANO.NE.0.)WRITE (IPR,154)                                     PULV0515
      IFOO=SATO*(ABS(SATO)+0.5)/SATO                                    PULV0516
C-----WRITE F(000)                                                      PULV0517
      IF (KODLP.NE.2) WRITE (IPR,155) IFOO                              PULV0518
C-----PRINT ATOM POSITIONS                                              PULV0519
 79   WRITE (IPR,198)                                                   PULV0520
      DO 80 M=1,NCOMPO                                                  PULV0521
      NL=NA(M)                                                          PULV0522
C-----PRINT ATOM COORDINATES                                            PULV0523
      WRITE (IPR,199) (ELEMT(M),IDE(I,M),X(I,M),Y(I,M),Z(I,M),FMULT(I,M)PULV0524
     1,FOCCU(I,M),BTEMP(I,M),I=1,NL)                                    PULV0525
 80   CONTINUE                                                          PULV0526
C-----EXIT IF NUMBER OF REFLECTIONS LESS THAN TWO                       PULV0527
      IF(J.LE.1) GO TO 206                                              PULV0528
C-----START ORDERING REFLEXIONS                                         PULV0529
      DO 81 N=1,J                                                       PULV0530
      NN=N+1                                                            PULV0531
      DO 81 M=NN,JJ                                                     PULV0532
      IF ((Q(N)-Q(M)).LE.0.) GO TO 81                                   PULV0533
      TEMP=Q(N)                                                         PULV0534
      Q(N)=Q(M)                                                         PULV0535
      Q(M)=TEMP                                                         PULV0536
      TEMP=YH(N)                                                        PULV0537
      YH(N)=YH(M)                                                       PULV0538
      YH(M)=TEMP                                                        PULV0539
      TEMP=YK(N)                                                        PULV0540
      YK(N)=YK(M)                                                       PULV0541
      YK(M)=TEMP                                                        PULV0542
      TEMP=YL(N)                                                        PULV0543
      YL(N)=YL(M)                                                       PULV0544
      YL(M)=TEMP                                                        PULV0545
C-----END OF ORDERING                                                   PULV0546
 81   CONTINUE                                                          PULV0547
C-----START LOOP TO CALCULATE F FOR ALL STORED REFLEXIONS               PULV0548
      DO 107 N=1,JJ                                                     PULV0549
      IF (Q(N).GT.1.)GO TO 133                                          PULV0550
      THETA(N)=57.29578*ATAN(SQRT(Q(N)/(1.-Q(N))))                      PULV0551
C-----CALCULATE LORENTZ POLARISATION FACTORS                            PULV0552
      VV=THETA(N)*0.0174533                                             PULV0553
      SX2=(SIN(VV)/WL)**2                                               PULV0554
      PLG=1.                                                            PULV0555
      IF (KODLP.EQ.0) PLG=(1.+(1.-2.*Q(N))**2)/(2.*Q(N)*SQRT(1.-Q(N)))  PULV0556
      IF (KODLP.EQ.2) PLG=1./(Q(N)*SQRT(1.-Q(N)))                       PULV0557
      WW=(2.*THETA(N)-BGUIN)*0.0174533                                  PULV0558
      IF (KODLP.GT.2) PLG=(1.+(1.-2.*Q(N))**2 *AGUIN)/((1.+AGUIN)*Q(N)*SPULV0559
     1QRT(1.-Q(N))*COS(WW))                                             PULV0560
C-----CALCULATE MULTIPLICITY FOR POWDERLINE                             PULV0561
      GO TO (82,84,87,89,91,93,96), ISYSTM                              PULV0562
 82   IF ((YK(N).EQ.0.).OR.((YH(N).EQ.0.).AND.(YL(N).EQ.0.))) GO TO 96  PULV0563
 83   FMULTI=4.0                                                        PULV0564
      GO TO 98                                                          PULV0565
 84   IF (YH(N).EQ.0.) IF (YK(N)) 133,96,86                             PULV0566
      IF (YK(N).EQ.0.) GO TO 86                                         PULV0567
      IF (YL(N).EQ.0.) GO TO 83                                         PULV0568
 85   FMULTI=8.0                                                        PULV0569
      GO TO 98                                                          PULV0570
 86   IF (YL(N)) 133,96,83                                              PULV0571
 87   IF ((YH(N).EQ.0.).AND.(YK(N).EQ.0.)) GO TO 96                     PULV0572
 88   FMULTI=6.0                                                        PULV0573
      GO TO 98                                                          PULV0574
 89   IF ((YH(N)-YK(N)).EQ.0.) IF (YH(N)) 133,96,90                     PULV0575
      IF (YK(N).EQ.0.) GO TO 90                                         PULV0576
      IF (YL(N).EQ.0.) IF (LAUE-1) 133,83,85                            PULV0577
      IF (LAUE.EQ.1) GO TO 85                                           PULV0578
      FMULTI=16.                                                        PULV0579
      GO TO 98                                                          PULV0580
 90   IF (YL(N)) 133,83,85                                              PULV0581
 91   IF ((YH(N)-YK(N)).EQ.0.) IF (YL(N)) 133,97,92                     PULV0582
      IF ((YL(N).EQ.0.).AND.(LAUE.EQ.2)) IF (YK(N)) 133,88,94           PULV0583
      IF ((YL(N).EQ.0.).AND.(LAUE.EQ.1)) IF (YK(N)) 133,88,97           PULV0584
      IF (((YK(N)-YL(N)).EQ.0.).OR.(LAUE.EQ.1)) GO TO 94                PULV0585
      FMULTI=48.                                                        PULV0586
      GO TO 98                                                          PULV0587
 92   IF (YH(N)-YL(N)) 133,85,94                                        PULV0588
 93   IF ((YH(N)-YK(N)).EQ.0.) IF (YH(N)) 133,96,95                     PULV0589
      IF (YK(N).EQ.0.) GO TO 95                                         PULV0590
      IF ((YL(N).EQ.0.).AND.(LAUE.EQ.1)) GO TO 88                       PULV0591
      IF ((YL(N).EQ.0.).OR.(LAUE.EQ.1)) GO TO 97                        PULV0592
 94   FMULTI=24.0                                                       PULV0593
      GO TO 98                                                          PULV0594
 95   IF (YL(N)) 133,88,97                                              PULV0595
 96   FMULTI=2.0                                                        PULV0596
      GO TO 98                                                          PULV0597
 97   FMULTI=12.0                                                       PULV0598
 98   SUMA(N)=0.                                                        PULV0599
      SUMB(N)=0.                                                        PULV0600
      SUMBX=0.                                                          PULV0601
      SUMAX=0.                                                          PULV0602
C-----LOOP OVER DIFFERENT KINDS OF ATOMS                                PULV0603
      DO 104 M=1,NCOMPO                                                 PULV0604
      DELTF=DELFI(M)                                                    PULV0605
      SMA=0.                                                            PULV0606
      SMB=0.                                                            PULV0607
      NL=NA(M)                                                          PULV0608
C-----LOOP OVER ALL ATOMS OF ONE KIND                                   PULV0609
      DO 100 I=1,NL                                                     PULV0610
C-----LOOP OVER EQUIVALENT POSITIONS                                    PULV0611
      DO 99 J=1,NS                                                      PULV0612
      XN=TS(1,J)+FS(1,1,J)*X(I,M)+FS(2,1,J)*Y(I,M)+FS(3,1,J)*Z(I,M)     PULV0613
      YN=TS(2,J)+FS(1,2,J)*X(I,M)+FS(2,2,J)*Y(I,M)+FS(3,2,J)*Z(I,M)     PULV0614
      ZN=TS(3,J)+FS(1,3,J)*X(I,M)+FS(2,3,J)*Y(I,M)+FS(3,3,J)*Z(I,M)     PULV0615
      ARG=PI2*(YH(N)*XN+YK(N)*YN+YL(N)*ZN)                              PULV0616
C-----INCLUDE OCCUPATION, MULTIPLICITY AND TEMPERATURE FACTOR           PULV0617
      SMA=SMA+DCOS(ARG)*FMULT(I,M)*FOCCU(I,M)*E**(-BTEMP(I,M)*SX2)      PULV0618
      IF (ISYMCE.EQ.1) GO TO 99                                         PULV0619
      SMB=SMB+DSIN(ARG)*FMULT(I,M)*FOCCU(I,M)*E**(-BTEMP(I,M)*SX2)      PULV0620
C-----END OF LOOP OVER EQUIVALENT POSITIONS                             PULV0621
 99   CONTINUE                                                          PULV0622
C-----END OF LOOP OVER ALL ATOMS OF ONE KIND                            PULV0623
 100  CONTINUE                                                          PULV0624
      IF (FNEUT(M).NE.0.)GO TO 102                                      PULV0625
C-----CALCULATE ATOMIC SCATT. FACTOR                                    PULV0626
      FSCAT=0.                                                          PULV0627
      DO 101 I=1,4                                                      PULV0628
      AR=-FB(I,M)*SX2                                                   PULV0629
      FSCAT=FSCAT+FA(I,M)*EXP(AR)                                       PULV0630
 101  CONTINUE                                                          PULV0631
C-----REAL PART OF SCATTERING FACTOR                                    PULV0632
      FSCAT=FSCAT+DELFR(M)+FC(M)                                        PULV0633
      GO TO 103                                                         PULV0634
C-----NEUTRON SCATTERING LENGTH                                         PULV0635
 102  FSCAT=FNEUT(M)                                                    PULV0636
C-----MULTIPLY WITH SCATTERING FACTOR AND STORE FOR OUTPUT              PULV0637
 103  SUMA(N)=SUMA(N)+SMA*FSCAT                                         PULV0638
      SUMB(N)=SUMB(N)+SMB*FSCAT                                         PULV0639
C-----CALCULATE IMAGINARY CORRECTION TERM FOR ANOMALOUS DISPERSION      PULV0640
      IF (ANO.EQ.0.)GO TO 104                                           PULV0641
      SUMAX=SUMAX+SMA*DELTF*FBRA*DUM                                    PULV0642
      SUMBX=SUMBX+SMB*DELTF*FBRA                                        PULV0643
C-----END OF LOOP OVER DIFFERENT KINDS OF ATOMS                         PULV0644
 104  CONTINUE                                                          PULV0645
C-----INCLUDE BRAVAIS MULTIPLICITY AND MULTIPLIER FOR CENTER AT ORIGIN  PULV0646
      SUMA(N)=FBRA*SUMA(N)*DUM                                          PULV0647
      SUMB(N)=FBRA*SUMB(N)                                              PULV0648
      FPLG(N)=PLG                                                       PULV0649
      FMUL(N)=FMULTI                                                    PULV0650
      IF (ANO.EQ.0.)GO TO 105                                           PULV0651
C-----CALCULATE TOTAL CORRECTION TERMS FOR ANOMALOUS DISPERSION         PULV0652
      FMULTI=FMULTI/2.                                                  PULV0653
      AX(N)=SUMA(N)-SUMBX                                               PULV0654
      AY(N)=SUMA(N)+SUMBX                                               PULV0655
      BX(N)=SUMB(N)+SUMAX                                               PULV0656
      BY(N)=-SUMB(N)+SUMAX                                              PULV0657
      STRU(N)=SUMA(N)**2+SUMB(N)**2+SUMAX**2+SUMBX**2                   PULV0658
      GO TO 106                                                         PULV0659
 105  STRU(N)=SUMA(N)**2+SUMB(N)**2                                     PULV0660
 106  VINT(N)=PLG*FMULTI*STRU(N)                                        PULV0661
C-----FIND MAXIMAL INTENSITY FOR NORMALISATION TO 1000.                 PULV0662
      VMXINT=AMAX1(VMXINT,VINT(N))                                      PULV0663
C-----END OF LOOP TO CALCULATE F FOR ALL STORED AND ORDERED HKL VALUES  PULV0664
 107  CONTINUE                                                          PULV0665
C-----OUTPUT OF JJ LINES WITH REFLECTION DATA                           PULV0666
      N=1                                                               PULV0667
      IF (NORM.EQ.3) N=3                                                PULV0668
      WRITE (IPR,156) ITIT(N),ITIT(N+1)                                 PULV0669
C-----SKIP TABULAR LIST                                                 PULV0670
      IF (NORM.EQ.3) GO TO 122                                          PULV0671
      WRITE (IPR,157)                                                   PULV0672
      NLINE=57                                                          PULV0673
      K=KODLP+1                                                         PULV0674
      I=NORM+1                                                          PULV0675
      DO 121 N=1,JJ                                                     PULV0676
      IF (NLINE.NE.57) GO TO 115                                        PULV0677
C-----PRINT HEADING OF PAGES                                            PULV0678
      GO TO (110,109,108,122), I                                        PULV0679
 108  WRITE (IPR,200)                                                   PULV0680
      GO TO 114                                                         PULV0681
 109  WRITE (IPR,201)                                                   PULV0682
      GO TO 114                                                         PULV0683
 110  GO TO (112,112,112,111,111), K                                    PULV0684
 111  J=5                                                               PULV0685
      GO TO 113                                                         PULV0686
 112  J=7                                                               PULV0687
 113  WRITE (IPR,202) ITIT(J),ITIT(J+1)                                 PULV0688
 114  NLINE=0                                                           PULV0689
 115  CONTINUE                                                          PULV0690
      IH=YH(N)                                                          PULV0691
      IK=YK(N)                                                          PULV0692
      IL=YL(N)                                                          PULV0693
      M=FMUL(N)                                                         PULV0694
      DVAL=WL/(2.*SQRT(Q(N)))                                           PULV0695
      THETA2=2.*THETA(N)                                                PULV0696
      IF (KODLP.GT.2) THETA2=THETA(N)*(DURCHM/28.64789)                 PULV0697
      PRPINT=VINT(N)*1000./VMXINT                                       PULV0698
      VVV=Q(N)                                                          PULV0699
      DSQ=1./(DVAL*DVAL)                                                PULV0700
      SUMAN=SUMA(N) +0.000001                                           PULV0701
      SUMBN=SUMB(N)                                                     PULV0702
      STRU1=STRU(N)                                                     PULV0703
      STRU1=SQRT(STRU1)                                                 PULV0704
C-----ANOMALOUS DISPERSION FOR FRIEDEL PAIRS                            PULV0705
      IF (ANO.EQ.0.)GO TO 116                                           PULV0706
      A1=AX(N) +0.000001                                                PULV0707
      A2=AY(N) +0.000001                                                PULV0708
      B1=BX(N)                                                          PULV0709
      B2=BY(N)                                                          PULV0710
      SUMBN=B1                                                          PULV0711
      STRU1=A1*A1+B1*B1                                                 PULV0712
      STRU2=A2*A2+B2*B2                                                 PULV0713
      STRU1=SQRT(STRU1)                                                 PULV0714
      STRU2=SQRT(STRU2)                                                 PULV0715
      PHA1=(ATAN2(B1,A1))*360./PI2                                      PULV0716
      PHA2=(ATAN2(B2,A2))*360./PI2                                      PULV0717
 116  IF ((SUMAN.NE.0.).OR.(SUMBN.NE.0.)) PHANG=(ATAN2(SUMBN,SUMAN))*360PULV0718
     1./PI2                                                             PULV0719
      GO TO (117,118,119,121), I                                        PULV0720
 117  WRITE (IPR,203) IH,IK,IL,THETA(N),THETA2,DVAL,DSQ  ,Q(N),IH,IK,IL,PULV0721
     1PRPINT,STRU1,SUMAN,SUMBN,PHANG,M,FPLG(N)                          PULV0722
      GO TO 120                                                         PULV0723
 118  WRITE (IPR,204) IH,IK,IL,THETA(N),Q(N),PRPINT,VINT(N),STRU1,SUMAN,PULV0724
     1SUMBN,PHANG,M,FPLG(N)                                             PULV0725
      GO TO 120                                                         PULV0726
 119  WRITE (IPR,205) IH,IK,IL,THETA(N),THETA2,DVAL,Q(N),IH,IK,IL,PRPINTPULV0727
     1,STRU1,STRU2,A1,A2,B1,B2,PHA1,PHA2,M,FPLG(N)                      PULV0728
 120  NLINE=NLINE+1                                                     PULV0729
C-----END OF OUTPUT OF NUMERICAL VALUES                                 PULV0730
 121  CONTINUE                                                          PULV0731
C-----GRAPHIC OUTPUT OF INTENSITIES                                     PULV0732
 122  N=3                                                               PULV0733
      IF (IMAGE.EQ.0) GO TO 123                                         PULV0734
      N=1                                                               PULV0735
      STEP=1./(2.*FLOAT(IMAGE))                                         PULV0736
 123  WRITE (IPR,158) ITIT(N),ITIT(N+1)                                 PULV0737
      IF (IMAGE.EQ.0) GO TO 1                                           PULV0738
      WRITE (IPR,159) STEP                                              PULV0739
      VMXINT=0.                                                         PULV0740
C-----TAKE THIS STATEMENT OUT (GENEVA UNIVAC 1100 SPECIFIC)             PULV0741
C     CALL HEAD (COMPND,NT,IWL,ILP)                                     PULV0742
C-----SUPPRESS PAGE JUMP  (CHANGE SUBROUTINE PAG IF NECESSARY )         PULV0743
      CALL PAG                                                          PULV0744
      WRITE (IPR,166) COMPND,WL,(IDL(I),I=MP,KK)                        PULV0745
C-----FIRST THETA VALUE                                                 PULV0746
      W(1)= TL                                                          PULV0747
C-----NUMBER OF INTERVALS                                               PULV0748
      KK=INT((TH-TL)/STEP + 1.)                                         PULV0749
C-----LOOP OVER ALL INTERVALS                                           PULV0750
      DO 125 K=1,KK                                                     PULV0751
      SP(K)=0.                                                          PULV0752
      FMUL(K)=0.                                                        PULV0753
      STRU(K)=0.                                                        PULV0754
      IF (K.NE.1) W(K)=W(K-1)+STEP                                      PULV0755
      VMA=0.                                                            PULV0756
      WK1=W(K)-0.5*STEP                                                 PULV0757
      WK2=WK1+STEP                                                      PULV0758
C-----LOOP OVER ALL REFLECTIONS IN ONE INTERVAL                         PULV0759
      DO 124 N=1,JJ                                                     PULV0760
      IF ((THETA(N).LT.WK1).OR.(THETA(N).GE.WK2)) GO TO 124             PULV0761
      VMA=AMAX1(VMA,VINT(N))                                            PULV0762
C-----STORE THE POINTER TO STRONGEST REFLECTION IN THIS INTERVAL        PULV0763
      IF (VMA.EQ.VINT(N)) FMUL(K)=FLOAT(N)                              PULV0764
C-----ACCUMULATE COINCIDENT INTENSITIES IN EACH INTERVAL                PULV0765
      SP(K)=SP(K)+VINT(N)                                               PULV0766
C-----COUNT NUMBER OF COINCIDING REFLECTIONS                            PULV0767
      STRU(K)=STRU(K)+1.                                                PULV0768
 124  CONTINUE                                                          PULV0769
C-----FIND LARGEST SUM OF INTENSITIES AMONG ALL INTERVALS               PULV0770
      VMXINT=AMAX1(VMXINT,SP(K))                                        PULV0771
 125  CONTINUE                                                          PULV0772
C-----FILL EACH OUTPUT LINE WITH STARS, BLANKS, DOTS ETC                PULV0773
      DO 131 K=1,KK                                                     PULV0774
      NSPIEL=SP(K)*100./(VMXINT)+.5                                     PULV0775
      NSP10=(NSPIEL-1)/10                                               PULV0776
      N=FMUL(K)                                                         PULV0777
      IH=YH(N)                                                          PULV0778
      IK=YK(N)                                                          PULV0779
      IL=YL(N)                                                          PULV0780
      I=STRU(K)                                                         PULV0781
      DO 126 MP=1,100                                                   PULV0782
      IPLA(MP)=IBLNK                                                    PULV0783
      IF (W(K).EQ.0.) IPLA(MP)=ISTA                                     PULV0784
 126  CONTINUE                                                          PULV0785
      IF (STRU(K).EQ.0.)GO TO 130                                       PULV0786
      IF (NSPIEL.EQ.0) GO TO 129                                        PULV0787
      DO 127 MP=1,NSPIEL                                                PULV0788
 127  IPLA(MP)=ISTA                                                     PULV0789
      IF (NSP10.LT.1) GO TO 129                                         PULV0790
      DO 128 J=1,NSP10                                                  PULV0791
      MP=10*J                                                           PULV0792
 128  IPLA(MP)=IDT(J)                                                   PULV0793
C-----WRITE ONE LINE OF GRAPHICAL OUTPUT WITH HKL OF STRONGEST INTENS.  PULV0794
 129  WRITE (IPR,160) IH,IK,IL,I,W(K),(IPLA(MP),MP=1,100)               PULV0795
      GO TO 131                                                         PULV0796
C-----WRITE ONE LINE OF GRAPHICAL OUTPUT WITHOUT HKL                    PULV0797
 130  WRITE (IPR,167) W(K),(IPLA(MP),MP=1,100)                          PULV0798
 131  CONTINUE                                                          PULV0799
      WRITE (IPR,161)                                                   PULV0800
C-CDC--TAKE THE FOLLOWING STATEMENT OUT (REINITIALIZES PAGE JUMP)       PULV0801
C-----THIS STATEMENT IS UNIVAC 1100 GENEVA SPECIFIC                     PULV0802
      GO TO 1                                                           PULV0803
C-----REDUCE UPPER THETA LIMIT AND TRY AGAIN                            PULV0804
  132 TH1=TH-5.                                                         PULV0805
      WRITE (IPR,195)  LIMIT1,TH,TH1                                    PULV0806
      IF(TH1.LE.SL) GO TO 206                                           PULV0807
      TH=TH1                                                            PULV0808
      SH=TH*PI2/360.                                                    PULV0809
      SH=(SIN(SH))**2                                                   PULV0810
      ICON=0                                                            PULV0811
      N=0                                                               PULV0812
      GO TO 8                                                           PULV0813
 133  WRITE (IPR,194)                                                   PULV0814
      GO TO 1                                                           PULV0815
 134  WRITE (IPR,162) NCOMPO                                            PULV0816
      GO TO 1                                                           PULV0817
 135  WRITE (IPR,163) NL                                                PULV0818
      GO TO 1                                                           PULV0819
 136  WRITE (IPR,164) NS                                                PULV0820
      GO TO 1                                                           PULV0821
  206 WRITE(IPR,207)                                                    PULV0822
      GO TO 1                                                           PULV0823
 137  STOP                                                              PULV0824
C-CDC-CALL EXIT                                                         PULV0825
C-----                                                                  PULV0826
 138  FORMAT (   ///,23H START  P U L V E R I X     )                   PULV0827
 139  FORMAT (/39H B Y E  B Y E  L A Z Y  P U L V E R I X  )            PULV0828
 140  FORMAT (4H JOB  ,I5,40H IS BAD DUE TO ERROR IN PREVIOUS PROGRAM,/1PULV0829
     16H GO TO NEXT JOB ,//)                                            PULV0830
 141  FORMAT (1H //////)                                                PULV0831
 142  FORMAT (4H1JOB,I5/ )                                              PULV0832
 143  FORMAT (/2X,9H DIAMETER,F9.4,3H MM,/2X,60H ANGLE BETWEEN NORMAL TOPULV0833
     1 PLANE OF SPECIMEN AND INCIDENT BEAM,F7.2,5H DEG.,/2X,27H D-SPACINPULV0834
     2G OF MONOCHROMATOR,F7.3,9H ANGSTROM)                              PULV0835
 144  FORMAT ( /12H SPACE GROUP,A4,22H GIVEN ON SPCGRP-CARD ,36A1)      PULV0836
 145  FORMAT (/1X,A4,14H LAUE SYMMETRY)                                 PULV0837
 146  FORMAT (/10H THERE IS ,A2,30H SYMMETRY CENTRE AT THE ORIGIN)      PULV0838
 147  FORMAT (/1X,3A4,16H BRAVAIS LATTICE)                              PULV0839
 148  FORMAT ( /41H CONDITIONS LIMITING POSSIBLE REFLECTIONS  /)        PULV0840
 149  FORMAT (/ 32H SCATTERING FACTOR  COEFFICIENTS/   )                PULV0841
 150  FORMAT (/1X,A4,2X,3H F=,F6.3,6H CM-12/)                           PULV0842
 151  FORMAT (1X,A4,9F9.5,/5X,21H NUMBER OF ELECTRONS=,I5,9X,           PULV0843
     X37H(CALCULATED USING ABOVE COEFFICIENTS))                         PULV0844
 152  FORMAT (6X,6HDELFR=,F7.3,2X,6HDELFI=,F7.3,5X,40H (ANOMALOUS DISPERPULV0845
     XSION CORRECTION TERMS)/)                                          PULV0846
 153  FORMAT ( /52H NO CORRECTION FOR ANOMALOUS DISPERSION WILL BE MADE)PULV0847
 154  FORMAT ( /49H CORRECTION FOR ANOMALOUS DISPERSION WILL BE MADE)   PULV0848
 155  FORMAT (/ 45H NUMBER OF ELECTRONS IN UNIT CELL   F(0,0,0)=,I8)    PULV0849
 156  FORMAT (/// 1X,50(1H-),//41H - T A B U L A R  L I S T  OF INTENSITPULV0850
     1IES,2A4,2H -//1X,50(1H-))                                         PULV0851
 157  FORMAT (//20H THE COLUMNS CONTAIN//21H MILLER INDICES (HKL)/,20H BPULV0852
     1RAGG ANGLE (THETA),/68H ANGLE (2THETA) OR THE DISTANCE IN MM OF A PULV0853
     2LINE FROM THE ORIGIN (MM),/25H D-VALUE AND/OR 1/D**2     /58H SQUAPULV0854
     3RE OF SINE (THETA)  MULTIPLIED BY 1000 (SIN2*1000)   ,/91H INTENSIPULV0855
     4TY OF A POWDER LINE, SCALED TO 1000 OR UNSCALED   (INTENSITY OR INPULV0856
     5TENSITY UNSCALED),/39H STRUCTURE FACTOR  (/F(HKL)/)          /60H PULV0857
     6REAL AND IMAGINARY PART OF STRUCTURE FACTOR (A(HKL),B(HKL)),/23H PPULV0858
     7HASE ANGLE (PHA.ANG.)/40H MULTIPLICITY OF THE POWDER LINE (MULT) /PULV0859
     899H LORENTZ-POLARISATION FACTOR FOR X RAY DIFFRACTION, OR LORENTZ PULV0860
     9FACTOR FOR NEUTRON DIFFRACTION (LPG) //94H THE EXACT NUMBER OF COLPULV0861
     $UMNS DEPENDS ON THE INPUT VARIABLES SYMLP,NORM,IANO ON THE CONDIT PULV0862
     $CARD/97H IN THE CASE OF ANOMALOUS DISPERSION THE STRUCTURE FACTORSPULV0863
     $ AND PHASE ANGLES ARE LISTED SEPARATELY/90H FOR THE ANTIREFLECTIONPULV0864
     $S (/F+(HKL)/,/F-(HKL)/,A+(HKL),A-(HKL),B+(HKL),B-(HKL),PHA+,PHA-) PULV0865
     $///////)                                                          PULV0866
 158  FORMAT (///1X,70(1H-),//,68H - G R A P H I C  R E P R E S E N T A PULV0867
     1T I O N  OF THE POWDER PATTERN ,2A4,2H -//1X,70(1H-))             PULV0868
 159  FORMAT (//46H THE POWDER PATTERN WILL BE GIVEN IN STEPS OF ,F7.4  PULV0869
     1,6H THETA//61H THE THETA VALUES INDICATED ARE THE CENTRES OF THE IPULV0870
     2NTERVALS //50H EACH LINE CONTAINS FROM THE LEFT TO THE RIGHT    //PULV0871
     392H THE MILLER INDICES OF THE STRONGEST REFLECTION CONTRIBUTING TOPULV0872
     4 THE INTENSITY   ( H K L )   ,/     54H THE NUMBER OF REFLECTIONS PULV0873
     5FALLING IN THE INTERVAL (N) ,/56H THE THETA VALUE OF THE CENTER OFPULV0874
     6 THE INTERVAL  (THETA) /92H THE INTENSITY OF THE SUM OF ALL REFLECPULV0875
     7TIONS FALLING IN THE INTERVAL (MAXIMUM=100 ASTERISKS))            PULV0876
 160  FORMAT(1H*,3I3,5X,I2,F8.2,1X,1HI,100A1,1HI)                       PULV0877
CDC----1X  SHOULD BE REPLACED BY 1HS TO SUPPRESS PAGE JUMP              PULV0878
 161  FORMAT (26X,102(1H-),///)                                         PULV0879
 162  FORMAT (22H NUMBER OF ATOM KINDS=,I5,10H TOO LARGE)               PULV0880
 163  FORMAT (29H NUMBER OF ATOMS OF ONE KIND=,I5,10H TOO LARGE)        PULV0881
 164  FORMAT (41H NUMBER OF SYMMETRY EQUIVALENT POSITIONS=,I5,10H TOO LAPULV0882
     1RGE)                                                              PULV0883
 165  FORMAT (/27H INTENSITY CALCULATION FOR ,19A4/)                    PULV0884
 166  FORMAT (/26H1 DIFFRACTION PATTERN FOR ,18A4,A2,4H WL=,F8.5,5A4// ,PULV0885
     12X,24HH  K  L       N   THETA ,102(1H-))                          PULV0886
 167  FORMAT (1H*,16X,F8.2,1X,1HI,100A1,1HI)                            PULV0887
CDC----1X  SHOULD BE REPLACED BY 1HS TO SUPPRESS PAGE JUMP              PULV0888
 168  FORMAT(3H A=,F9.5/3H B=,F9.5/3H C=,F9.5/6H BETA=,F9.5/4H WL=,F8.5)PULV0889
 169  FORMAT (3H A=,F9.5/3H B=,F9.5/3H C=,F9.5/4H WL=,F8.5/)            PULV0890
 170  FORMAT (3H A=,F9.5/3H C=,F9.5/4H WL=,F8.5)                        PULV0891
 171  FORMAT (3H A=,F9.5/4H WL=,F8.5)                                   PULV0892
 172  FORMAT (3H A=,F9.5/3H B=,F9.5/3H C=,F9.5/7H ALPHA=,F9.5/6H BETA=, PULV0893
     1F9.5/7H GAMMA=,F9.5/4H WL=,F8.5)                                  PULV0894
 173  FORMAT(/26H CALCULATION BETWEEN TL = ,F4.1,9H AND TH =,F6.1,      PULV0895
     116H DEGREES THETA  ,//23H DIFFRACTION GEOMETRY =,5A4)             PULV0896
 174  FORMAT (19H HKO WITH H=2N ONLY)                                   PULV0897
 175  FORMAT (19H HKO WITH K=2N ONLY)                                   PULV0898
 176  FORMAT (14H HKO WITH H+K=,I1,6HN ONLY)                            PULV0899
 177  FORMAT (19H OKL WITH K=2N ONLY)                                   PULV0900
 210  FORMAT (19H OKL WITH L=2N ONLY)                                   PULV0901
 178  FORMAT (14H OKL WITH K+L=,I1,6HN ONLY)                            PULV0902
 179  FORMAT (19H HOL WITH H=2N ONLY)                                   PULV0903
 180  FORMAT (19H HOL WITH L=2N ONLY)                                   PULV0904
 181  FORMAT (14H HOL WITH H+L=,I1,6HN ONLY)                            PULV0905
 182  FORMAT (19H HHL WITH L=2N ONLY)                                   PULV0906
 183  FORMAT (22H HHL WITH 2H+L=4N ONLY)                                PULV0907
 184  FORMAT (12H HOO WITH H=,I1,6HN ONLY)                              PULV0908
 185  FORMAT (12H OKO WITH K=,I1,6HN ONLY)                              PULV0909
 186  FORMAT (12H OOL WITH L=,I1,6HN ONLY)                              PULV0910
 187  FORMAT (/21H MONOCLINIC STRUCTURE)                                PULV0911
 188  FORMAT (/20H TRICLINIC STRUCTURE)                                 PULV0912
 189  FORMAT (/23H ORTHORHOMBIC STRUCTURE)                              PULV0913
 190  FORMAT (/19H TRIGONAL STRUCTURE)                                  PULV0914
 191  FORMAT (/21H TETRAGONAL STRUCTURE)                                PULV0915
 192  FORMAT (/16H CUBIC STRUCTURE)                                     PULV0916
 193  FORMAT (/20H HEXAGONAL STRUCTURE)                                 PULV0917
 194  FORMAT(/53H SOMETHING VERY BAD HAPPENED. CALL THE AUTHORS PLEASE) PULV0918
 195  FORMAT (/11H *OVERFLOW*,/38H NUMBER OF REFLECTIONS IS GREATER THANPULV0919
     1,I5,/42H *** UPPER THETA LIMIT *** IS REDUCED FROM,F6.2,4H TO ,   PULV0920
     XF5.2/)                                                            PULV0921
 196  FORMAT (/ 29H NUMBER OF ATOMS IN UNIT CELL//,32H ELEMENT NUMBER*  PULV0922
     10CCUP=  NTOTAL)                                                   PULV0923
 197  FORMAT (2X,A4,A2,F7.1,1H*,F7.3,1H=,F8.3)                          PULV0924
 198  FORMAT (/ 16H ATOM  POSITIONS// 19H ELEMENT   X/A     ,38H Y/B    PULV0925
     1  Z/C    FMULT   OCCUP   BTEMP)                                   PULV0926
 199  FORMAT (1X,A4,A2,3F9.6,F7.4,F8.4,F7.3)                            PULV0927
 200  FORMAT (1H1,131H H  K  L THETA  MM     D     SIN2   H  K  L INTENSPULV0928
     1    F+(HKL)    F-(HKL)  A+(HKL)  A-(HKL)  B+(HKL)  B-(HKL) PHA+  PPULV0929
     2HA- MULT   LPG /)                                                 PULV0930
 201  FORMAT(/130H1 H  K  L    THETA  SIN2*1000 INT.SCALED   INTENSITY UPULV0931
     1NSCALED           /F(HKL)/        A(HKL)        B(HKL) PHA.ANG. MUPULV0932
     2LT    LPG   /)                                                    PULV0933
 202  FORMAT(/18H1 H  K  L  THETA  ,2A3,107H D VALUE  1/D**2 SIN2*1000  PULV0934
     1H  K  L INTENSITY         /F(HKL)/       A(HKL)      B(HKL) PHA.ANPULV0935
     2G. MULT   LPG  /)                                                 PULV0936
 203  FORMAT (3I3,2F7.2,F9.4,1X,F7.4,3PF9.2,1X,3I3,0PF10.1,0PF17.1,0P2F1PULV0937
     13.2,0PF8.2,I3,0PF7.2)                                             PULV0938
 204  FORMAT (3I3,F9.2,3P1F10.2,0PF10.1,0PF22.1,0PF20.1,0P2F14.2,0PF8.2,PULV0939
     1I3,0PF8.2)                                                        PULV0940
 205  FORMAT (3I3,2F6.1,F8.4,3PF6.1,3I3,0PF7.1,0P2F11.1,0P4F9.1,0P2F6.1,PULV0941
     1I3,F7.2)                                                          PULV0942
 207  FORMAT(/13H * BAD LUCK */63H ONLY ONE (OR NO) REFLECTION FALLS IN PULV0943
     XTHE THETA RANGE SPECIFIED/37H NO POWDER PATTERN WILL BE CALCULATEDPULV0944
     X)                                                                 PULV0945
 208  FORMAT(10H HKL  NONE)                                             PULV0946
 209  FORMAT(21H HKL WITH K+L=2N ONLY)                                  PULV0947
 215  FORMAT(21H HKL WITH H+L=2N ONLY)                                  PULV0948
 211  FORMAT(21H HKL WITH H+K=2N ONLY)                                  PULV0949
 212  FORMAT(40H HKL WITH H,K,L ALL EVEN OR ALL ODD ONLY )              PULV0950
 213  FORMAT(23H HKL WITH H+K+L=2N ONLY)                                PULV0951
 214  FORMAT(24H HKL WITH -H+K+L=3N ONLY)                               PULV0952
      END                                                               PULV0953
      SUBROUTINE EQUI                                                   EQUI0000
C-----PRINTS EQUIPOINTS STORED IN TS,FS,ISYMCE AND IBRAVL               EQUI0001
      COMMON /EQUO/ TS,FS,NG,ISYMCE,IBRAVL                              EQUI0002
      COMMON /UNITS/ NPT                                                EQUI0003
      INTEGER DIG,SYMB1,SYMB2                                           EQUI0004
      DIMENSION TS(3,24), FS(3,3,24), CON1(7), SYMB1(8), SYMB2(9), DIG(1EQUI0005
     13), IB(24), IP(12), N3(9)                                         EQUI0006
      DATA IB(1)/4H1/2 /,IB(2)/4H2/3 /,IB(3)/4H1/2 /,IB(4)/4H 0  /,IB(5)EQUI0007
     1/4H1/2 /,IB(6)/4H1/2 /,IB(7)/4H1/2 /,IB(8)/4H1/3 /,IB(9)/4H1/2 /,IEQUI0008
     2B(10)/4H1/2 /,IB(11)/4H 0  /,IB(12)/4H1/2 /,IB(13)/4H1/2)/,IB(14)/EQUI0009
     34H1/3 /,IB(15)/4H 0, /,IB(16)/4H1/2)/,IB(17)/4H1/2)/,IB(18)/4H 0 )EQUI0010
     4/,IB(19)/4H1/3 /,IB(20)/4H1/2 /,IB(21)/4H2/3 /,IB(22)/4H 0  /,IB(2EQUI0011
     53)/4H2/3)/,IB(24)/4H1/2,/                                         EQUI0012
      DATA CON1(1)/0.75/,CON1(2)/0.6667/,CON1(3)/0.5/,CON1(4)/0.3333/,COEQUI0013
     1N1(5)/0.25/,CON1(6)/0.16667/,CON1(7)/0.83333/                     EQUI0014
      DATA SYMB1(1)/3H3/4/,SYMB1(2)/3H2/3/,SYMB1(3)/3H1/2/,SYMB1(4)/3H1/EQUI0015
     13/,SYMB1(5)/3H1/4/,SYMB1(6)/3H1/6/,SYMB1(7)/3H5/6/,SYMB1(8)/3H   /EQUI0016
      DATA SYMB2(1)/3H +X/,SYMB2(2)/3H  X/,SYMB2(3)/3H -X/,SYMB2(4)/3H +EQUI0017
     1Y/,SYMB2(5)/3H  Y/,SYMB2(6)/3H -Y/,SYMB2(7)/3H +Z/,SYMB2(8)/3H  Z/EQUI0018
     2,SYMB2(9)/3H -Z/                                                  EQUI0019
      DATA N3(1)/1H /,N3(2)/3H   /,N3(3)/4H    /,N3(4)/1H,/,N3(5)/4H+(0 EQUI0020
     1/,N3(6)/4H0 0,/,N3(7)/4H 0  /,N3(8)/4H1/2 /,N3(9)/4H1/2)/         EQUI0021
      WRITE (NPT,15)                                                    EQUI0022
      DIG(13)=N3(1)                                                     EQUI0023
      IF (ISYMCE.EQ.1) DIG(13)=N3(4)                                    EQUI0024
C-----FILL OUTPUT STRING WITH BLANKS                                    EQUI0025
      DO 1 NN=1,12                                                      EQUI0026
      IP(NN)=N3(3)                                                      EQUI0027
 1    DIG(NN)=SYMB1(8)                                                  EQUI0028
C-----FILL OUTPUT STRING IP WITH BRAVAIS LATTICE VECTORS                EQUI0029
      IF (IBRAVL.LT.2) GO TO 4                                          EQUI0030
C-----FIRST VECTOR                                                      EQUI0031
      IP(1)=N3(5)                                                       EQUI0032
      IP(2)=N3(6)                                                       EQUI0033
C-----SECOND VECTOR                                                     EQUI0034
      DO 2 I=1,3                                                        EQUI0035
      I1=I+2                                                            EQUI0036
      I2=IBRAVL-1                                                       EQUI0037
      I3=I*6-6                                                          EQUI0038
 2    IP(I1)=IB(I2+I3)                                                  EQUI0039
      IF ((IBRAVL.LT.3).OR.(IBRAVL.GT.4)) GO TO 4                       EQUI0040
C-----THIRD VECTOR                                                      EQUI0041
      I2=16+IBRAVL                                                      EQUI0042
      DO 3 I=1,3                                                        EQUI0043
      I1=I+5                                                            EQUI0044
      I3=I*2-2                                                          EQUI0045
 3    IP(I1)=IB(I2+I3)                                                  EQUI0046
C-----FORTH VECTOR                                                      EQUI0047
      IF (IBRAVL.EQ.3) GO TO 4                                          EQUI0048
      IP(9)=N3(7)                                                       EQUI0049
      IP(10)=N3(8)                                                      EQUI0050
      IP(11)=N3(9)                                                      EQUI0051
C-----LOOP OVER NUMBER OF EQUIPOINTS                                    EQUI0052
 4    DO 14 I=1,NG                                                      EQUI0053
C-----FILL OUTPUT STRING WITH BLANKS                                    EQUI0054
      DO 5 NN=1,12                                                      EQUI0055
 5    DIG(NN)=N3(2)                                                     EQUI0056
      ANTI=1.                                                           EQUI0057
      NN=1                                                              EQUI0058
C-----LOOP OVER X Y Z  COORDINATES                                      EQUI0059
 6    DO 12 J=1,3                                                       EQUI0060
      TS1=ANTI*TS(J,I)                                                  EQUI0061
      IF (TS1.LT.0.) TS1=1.+TS1                                         EQUI0062
      N1=1                                                              EQUI0063
      IF (TS1.EQ.0.) GO TO 9                                            EQUI0064
      DO 7 II=1,7                                                       EQUI0065
      DIF=TS1-CON1(II)                                                  EQUI0066
      DIF=ABS(DIF)                                                      EQUI0067
      IF (DIF.LT..010) GO TO 8                                          EQUI0068
 7    CONTINUE                                                          EQUI0069
      WRITE (NPT,16)                                                    EQUI0070
      RETURN                                                            EQUI0071
 8    DIG(NN)=SYMB1(II)                                                 EQUI0072
      NN=NN+1                                                           EQUI0073
      N1=2                                                              EQUI0074
 9    L=1                                                               EQUI0075
C-----LOOP OVER ROWS IN MATRIX                                          EQUI0076
      DO 11 M1=1,3                                                      EQUI0077
      FS1=ANTI*FS(M1,J,I)                                               EQUI0078
      IF (FS1.EQ.0.) GO TO 10                                           EQUI0079
      IF (FS1.EQ.1.) L=L-N1+2                                           EQUI0080
      IF (FS1.EQ.-1.) L=L+2                                             EQUI0081
      N1=N1+1                                                           EQUI0082
      DIG(NN)=SYMB2(L)                                                  EQUI0083
      NN=NN+1                                                           EQUI0084
 10   L=M1*3+1                                                          EQUI0085
 11   CONTINUE                                                          EQUI0086
      NN=NN-N1+3                                                        EQUI0087
 12   CONTINUE                                                          EQUI0088
      IF (ANTI.EQ.-1.) GO TO 13                                         EQUI0089
      ANTI=-1.                                                          EQUI0090
      IF (ISYMCE.EQ.1) GO TO 6                                          EQUI0091
 13   WRITE (NPT,17) (DIG(I1),I1=1,6),DIG(7),DIG(8),DIG(13),DIG(9),DIG(1EQUI0092
     10),DIG(13),DIG(11),DIG(12),(IP(I1),I1=1,12)                       EQUI0093
 14   CONTINUE                                                          EQUI0094
      RETURN                                                            EQUI0095
C                                                                       EQUI0096
 15   FORMAT (/27H EQUIVALENT POINT POSITIONS/)                         EQUI0097
 16   FORMAT (33H EQUIPOINT CODE BADLY INTERPRETED)                     EQUI0098
 17   FORMAT (1X,2(2A3,1H,),2A3,5X,2(2A3,A1),2A3,2X,12A4)               EQUI0099
      END                                                               EQUI0100
      SUBROUTINE PAG                                                    PAGE0000
C-----ROUTINE TO SUPPRESS PAGE JUMP FOR THE GRAPHIC OUTPUT              PAGE0001
      COMMON /UNITS/ IPR                                                PAGE0002
      WRITE (IPR,1)                                                     PAGE0003
    1 FORMAT (1H0)                                                      PAGE0004
C-----THIS IS A UNIVAC GENEVA SPECIFIC SUBROUTINE                       PAGE0005
C     CALL PAGE ('M,320,0,0',2)                                         PAGE0006
      RETURN                                                            PAGE0007
      END                                                               PAGE0008
                                                                                
                                                                                
                                                                                
                                                                                
                                                                                
                                                                                
                                                                                
                                                                                
